/* $Workfile: OtxDev.h $   $Revision: 43 $    $Modtime: 11/11/03 4:50p $  */
#ifndef OTX_DEV_H
#define OTX_DEV_H
/******************************************************************************

  Copyright (C) 1999 Odin TeleSystems Inc., All Rights Reserved.

  @doc PublicHwApi OtxDev

  OTX Generic Hardware Driver API

  @module
  OtxDev | Devices Types suppored by OTX driver API

  @contents2
  OtxDev.h |

  @index enum struct type | OtxDev

  @contents2
  OTX Device Types supported by the API (OtxDev.h) | OTX Driver Supported Device Types

  @head3 OTX Driver Supported Device Types |

  @index enum struct type | OtxDev

******************************************************************************/


// @type OTX_LDEVICE_VALUE | Convert logical device enum to a value which can be used as an index
#define OTX_GET_LDEVICE_TYPE_VALUE(h)      ((h) * -1)



/******************************************************************************
 @enum
    Type of physical device
******************************************************************************/
enum OtxPhysicalDeviceTypeE {
  OTX_DEVICE_UNKNOWN               =   0,     // @emem Used in error conditions
  OTX_DEVICE_DRIVER                =   1,     // @emem The root device that represents the driver
  OTX_DEVICE_ARNI_PCI              =   2,     // @emem Board Arni-16-PCI
  OTX_DEVICE_BALDER_PCMCIA         =   3,     // @emem Board Balder-2-PCMCIA
  OTX_DEVICE_BALDER_S_PCI          =   4,     // @emem Board Balder-8S-PCI
  OTX_DEVICE_BALDER_U_PCI          =   5,     // @emem Board Balder-8U-PCI
  OTX_DEVICE_THOR_PCI              =   6,     // @emem Board Thor-1-PCI, Thor-2-PCI
  OTX_DEVICE_THOR_PCMCIA           =   7,     // @emem Board Thor-2-PCMCIA and Thor-2-PCMCIA-Plus
  OTX_DEVICE_VIDAR_5x_PCI          =   8,     // @emem Board Vidar-5x8-PCI, Vidar-5x12-PCI, Vidar-5x16-PCI
  OTX_DEVICE_VIDAR_6x_PCI          =   9,     // @emem Board Vidar-6x3-PCI
  OTX_DEVICE_SIF_PCI               =  10,     // @emem Board Sif-16-PCI, Sif-32-PCI
  OTX_DEVICE_VIDAR_5x_ASM          =  11,     // @emem Board Vidar-5x2-ASM, Vidar-5x4-ASM
  OTX_DEVICE_VIDAR_6x_ASM          =  12,     // @emem Board Vidar-6x1-ASM
  OTX_DEVICE_VIDAR_55x4_ASM        =  13,     // @emem Board Vidar-55x4-ASM
  OTX_DEVICE_LI_CONTROLLER         =  14,     // @emem Line Interface Controller for a Line Interface Group
  OTX_DEVICE_LI_POTS               =  15,     // @emem Analog telephone Line Interface - Phone side (See OtxPots.h)
  OTX_DEVICE_LI_SLIC               =  16,     // @emem Analog telephone Line Interface - Line Interface Side
  OTX_DEVICE_LI_T1E1               =  17,     // @emem T1/E1 Line Interface (See OtxT1E1.h)
  OTX_DEVICE_LI_BRI_S              =  18,     // @emem ISDN BRI S/T Line Interface (See OtxBri.h)
  OTX_DEVICE_LI_BRI_U              =  19,     // @emem ISDN BRI U Line Interface (See OtxBri.h)
  OTX_DEVICE_HDLC                  =  20,     // @emem HDLC controller (See OtxHdlc.h)
  OTX_DEVICE_TSS                   =  21,     // @emem Time space switch (See OtxBrd.h)
  OTX_DEVICE_DSP                   =  22,     // @emem Digital Signal processor (See OtxDsp.h)
  OTX_DEVICE_PROCESSOR             =  23,     // @emem General Purpose Micro Processor
  OTX_DEVICE_PCI_BRIDGE            =  24,     // @emem PCI Board Bridge
  OTX_DEVICE_CODEC                 =  25,     // @emem A/D, D/A converter. Connected to a external handset and/or speaker
  OTX_DEVICE_EEPROM                =  26,     // @emem EEPROM. Storage of persistent data
  OTX_DEVICE_TBC                   =  27,     // @emem JTAG Test Bus Controller
  OTX_DEVICE_QUAD_T1E1             =  28,     // @emem Quad E1/T1 Device (hosting 4 OTX_DEVICE_LI_T1E1 devices)
  OTX_DEVICE_QUAD_CODEC            =  29,     // @emem Quad Codec (hosting 4 OTX_DEVICE_CODEC devices)
  OTX_DEVICE_THOR_8_PCI            =  30,     // @emem Board Thor-4-PCI, Thor-8-PCI
  OTX_DEVICE_CT_BUS                =  31,     // @emem CT Bus (H.100 or H.110) representing the cable which connects a number of boards
  OTX_DEVICE_HERMOD_PCI            =  32,     // @emem Board Hermod-PCI (PCI JTAG Adapter)
  OTX_DEVICE_GIMLE_16_PCI          =  33,     // @emem Board Gimle-16-PCI (8 span T1/E1 probe)
  OTX_DEVICE_VIDAR_5X1_ASM_BASIC   =  34,     // @emem Board Vidar-5x1-ASM-Basic
  OTX_DEVICE_THOR_1_PCI_BASIC      =  35,     // @emem Board Thor-1-PCI-Basic
  OTX_DEVICE_VIDAR_5X4_ASM_CST     =  36,     // @emem Board Vidar-5x4-ASM-CST
  OTX_DEVICE_VIDAR_5X4_ASM_V90     =  37,     // @emem Board Vidar-5x4-ASM-V90
  OTX_DEVICE_VIDAR_5X4_ASM_EX      =  38,     // @emem Board Vidar-5x4-ASM-EX
  OTX_DEVICE_THOR_8_PCI_PLUS       =  39,     // @emem Board Thor-8-PCI-Plus
  OTX_DEVICE_THOR_2_PCI_PLUS       =  40,     // @emem Board Thor-2-PCI-Plus
  OTX_DEVICE_SLEIPNIR_1_PCI        =  41,     // @emem Board Sleipnir-1-PCI
  OTX_DEVICE_VIDAR_55X12_PCI       =  42,     // @emem Board Vidar-55x12-PCI
  OTX_DEVICE_BURST                 =  43,     // @emem PCI DMA/Burst
  OTX_DEVICE_VIDAR_5X4_ASM_PRO     =  44,     // @emem Board Vidar-5x4-ASM-PRO
  OTX_DEVICE_END                   =  45
};


typedef enum OtxPhysicalDeviceTypeE OtxPhysicalDeviceTypeE;

/******************************************************************************
  @enum Type of logical device

  @comm Note that logical devices are numbered so that they don't overlap
  with physical devices, hence by using the number one can tell exactly
  what kind of logical or physical device it is. Only the 16 lower bits
  are used since we also support 16 bit platforms
******************************************************************************/
enum OtxLogicalDeviceTypeE {
  OTX_LDEVICE_UNKNOWN                      = - 0,   // @emem Used in error conditions
  OTX_LDEVICE_EVENT_QUEUE                  = - 1,   // @emem Event Queue, used for notifying the host application of occurring events
  OTX_LDEVICE_PIPE                         = - 2,   // @emem Pipe, used for connecting a data stream between two devices
  OTX_LDEVICE_TONE_CONST_VAL_GENERATOR     = - 3,   // @emem Logical Device for Generating Constant Value (See OtxTone.h)
  OTX_LDEVICE_TONE_EFFECTS_GENERATOR       = - 4,   // @emem Logical Device for Generating Tone Effects (See OtxTone.h)
  OTX_LDEVICE_TONE_SINEWAVE_GENERATOR      = - 5,   // @emem Logical Device for Generating Sine Wave (See OtxTone.h)
  OTX_LDEVICE_TONE_DTMF_GENERATOR          = - 6,   // @emem Logical Device for Generating single DTMF tone (See OtxTone.h)
  OTX_LDEVICE_TONE_MF_GENERATOR            = - 7,   // @emem Logical Device for Generating single MF tone (See OtxTone.h)
  OTX_LDEVICE_TONE_SEQUENCE_GENERATOR      = - 8,   // @emem Logical Device for Generating Sequence of Frequencies (See OtxTone.h)
  OTX_LDEVICE_TONE_DTMF_DIALER             = - 9,   // @emem Logical Device for Generating Sequence of DTMF tones (See OtxTone.h)
  OTX_LDEVICE_TONE_MF_DIALER               = -10,   // @emem Logical Device for Generating Sequence of MF tones (See OtxTone.h)

  OTX_LDEVICE_TONE_SILENCE_DETECTOR        = -11,   // @emem Logical Device for Silence Detection (See OtxTone.h)
  OTX_LDEVICE_TONE_DIALTONE_DETECTOR       = -12,   // @emem Logical Device for Dial Tone Detection (See OtxTone.h)
  OTX_LDEVICE_TONE_DTMF_DETECTOR           = -13,   // @emem Logical Device for DTMF Detection (See OtxTone.h)
  OTX_LDEVICE_TONE_MF_DETECTOR             = -14,   // @emem Logical Device for MF Detection (See OtxTone.h)
  OTX_LDEVICE_TONE_FSK_DETECTOR            = -15,   // @emem Logical Device for FSK Detection (See OtxTone.h)

  OTX_LDEVICE_DATA_RAW_SENDER              = -16,   // @emem Logical Device for Sending Raw Data (See OtxData.h)
  OTX_LDEVICE_DATA_RAW_RECEIVER            = -17,   // @emem Logical Device for Receiving Raw Data (See OtxData.h)
  OTX_LDEVICE_DATA_CONVERTER               = -18,   // @emem Logical Device for Converting from one data format to another (See OtxData.h)
  OTX_LDEVICE_DATA_MIXER                   = -19,   // @emem Multiplexes (mixes) N inputs to 1 output. Allows
                                                    //       device or pipe outputs to be connected together (See OtxData.h)
  OTX_LDEVICE_DATA_CONFERENCE_BRIDGE       = -20,   // @emem Conference Bridge. Conferences N inputs to N outputs. Allows
                                                    //       construction of multi-party conferences (See OtxData.h)

  OTX_LDEVICE_HDLC_SENDER                  = -21,   // @emem Logical Device for sending HDLC Framing (See OtxHdlc.h)
  OTX_LDEVICE_HDLC_RECEIVER                = -22,   // @emem Logical Device for receiving HDLC Framing (See OtxHdlc.h)

  OTX_LDEVICE_T1_ROB_BIT_ACCESS            = -23,   // @emem Logical Device for T1 Bit Rob Signalling for CAS (See OtxT1E1.h)
  OTX_LDEVICE_E1_S_BIT_ACCESS              = -24,   // @emem Logical Device for E1 Sa and Si bits access (See OtxT1E1.h)
  OTX_LDEVICE_E1_ABCD_BIT_ACCESS           = -25,   // @emem Logical Device for E1 ABCD bit access for CAS (See OtxT1E1.h)

  OTX_LDEVICE_MODEM_V34_SENDER             = -26,   // @emem V.34bis Modem Emulation Sender
  OTX_LDEVICE_MODEM_V34_RECEIVER           = -27,   // @emem V.34bis Modem Emulation Receiver

  OTX_LDEVICE_FAX_V17_SENDER               = -28,   // @emem V.17 Fax Emulation Sender
  OTX_LDEVICE_FAX_V17_RECEIVER             = -29,   // @emem V.17 Fax Emulation Receiver

  OTX_LDEVICE_VOICE_ECHO_CANCELLER         = -30,   // @emem Voice Echo Canceller
  OTX_LDEVICE_VOICE_SILENCE_SUPRESSOR      = -31,   // @emem Voice Silence Canceller
  OTX_LDEVICE_VOICE_CODEC_G723_ENCODER     = -32,   // @emem G.723 Voice Codec Encoder
  OTX_LDEVICE_VOICE_CODEC_G723_DECODER     = -33,   // @emem G.723 Voice Codec Decoder
  OTX_LDEVICE_VOICE_CODEC_G729_ENCODER     = -34,   // @emem G.729 Voice Codec Encoder
  OTX_LDEVICE_VOICE_CODEC_G729_DECODER     = -35,   // @emem G.729 Voice Codec Decoder

  OTX_LDEVICE_USER_APPLICATION             = -36,   // @emem DSP User Application compliant with the OTX DSP Software Development Kit (SDK)

  OTX_LDEVICE_TONE_VAL_SAMPLER             = -37,   // @emem Logical Device for reading an 8-bit incoming sample (See OtxTone.h)

  OTX_LDEVICE_T1_DL_BIT_ACCESS             = -38,   // @emem Logical Device for FS/DL Bit Access (See OtxT1E1.h)

  OTX_LDEVICE_TONE_DUAL_DETECTOR           = -39,   // @emem Logical Device for Dual Tone Detection (See OtxTone.h)

  OTX_LDEVICE_TONE_SINGLE_DETECTOR         = -40,   // @emem Logical Device for Single Tone Detection (See OtxTone.h)

  OTX_LDEVICE_END                          = 41     // @emem Odin internal. Positive number
};

typedef enum OtxLogicalDeviceTypeE OtxLogicalDeviceTypeE;

/******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

******************************************************************************/
#endif   // OTX_DEV_H
